Class: Aws::ARCZonalShift::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::ARCZonalShift::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-arczonalshift/client.rb,
sig/client.rbs
Overview
An API client for ARCZonalShift. To construct a client, you need to configure a :region and :credentials.
client = Aws::ARCZonalShift::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CancelPracticeRunResponseSuccess, _CancelZonalShiftResponseSuccess, _CreatePracticeRunConfigurationResponseSuccess, _DeletePracticeRunConfigurationResponseSuccess, _GetAutoshiftObserverNotificationStatusResponseSuccess, _GetManagedResourceResponseSuccess, _ListAutoshiftsResponseSuccess, _ListManagedResourcesResponseSuccess, _ListZonalShiftsResponseSuccess, _StartPracticeRunResponseSuccess, _StartZonalShiftResponseSuccess, _UpdateAutoshiftObserverNotificationStatusResponseSuccess, _UpdatePracticeRunConfigurationResponseSuccess, _UpdateZonalAutoshiftConfigurationResponseSuccess, _UpdateZonalShiftResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#cancel_practice_run(params = {}) ⇒ Types::CancelPracticeRunResponse
Cancel an in-progress practice run zonal shift in Amazon Application Recovery Controller.
-
#cancel_zonal_shift(params = {}) ⇒ Types::ZonalShift
Cancel a zonal shift in Amazon Application Recovery Controller.
-
#create_practice_run_configuration(params = {}) ⇒ Types::CreatePracticeRunConfigurationResponse
A practice run configuration for zonal autoshift is required when you enable zonal autoshift.
-
#delete_practice_run_configuration(params = {}) ⇒ Types::DeletePracticeRunConfigurationResponse
Deletes the practice run configuration for a resource.
-
#get_autoshift_observer_notification_status(params = {}) ⇒ Types::GetAutoshiftObserverNotificationStatusResponse
Returns the status of the autoshift observer notification.
-
#get_managed_resource(params = {}) ⇒ Types::GetManagedResourceResponse
Get information about a resource that's been registered for zonal shifts with Amazon Application Recovery Controller in this Amazon Web Services Region.
-
#list_autoshifts(params = {}) ⇒ Types::ListAutoshiftsResponse
Returns the autoshifts for an Amazon Web Services Region.
-
#list_managed_resources(params = {}) ⇒ Types::ListManagedResourcesResponse
Lists all the resources in your Amazon Web Services account in this Amazon Web Services Region that are managed for zonal shifts in Amazon Application Recovery Controller, and information about them.
-
#list_zonal_shifts(params = {}) ⇒ Types::ListZonalShiftsResponse
Lists all active and completed zonal shifts in Amazon Application Recovery Controller in your Amazon Web Services account in this Amazon Web Services Region.
-
#start_practice_run(params = {}) ⇒ Types::StartPracticeRunResponse
Start an on-demand practice run zonal shift in Amazon Application Recovery Controller.
-
#start_zonal_shift(params = {}) ⇒ Types::ZonalShift
You start a zonal shift to temporarily move load balancer traffic away from an Availability Zone in an Amazon Web Services Region, to help your application recover immediately, for example, from a developer's bad code deployment or from an Amazon Web Services infrastructure failure in a single Availability Zone.
-
#update_autoshift_observer_notification_status(params = {}) ⇒ Types::UpdateAutoshiftObserverNotificationStatusResponse
Update the status of autoshift observer notification.
-
#update_practice_run_configuration(params = {}) ⇒ Types::UpdatePracticeRunConfigurationResponse
Update a practice run configuration to change one or more of the following: add, change, or remove the blocking alarm; change the outcome alarm; or add, change, or remove blocking dates or time windows.
-
#update_zonal_autoshift_configuration(params = {}) ⇒ Types::UpdateZonalAutoshiftConfigurationResponse
The zonal autoshift configuration for a resource includes the practice run configuration and the status for running autoshifts, zonal autoshift status.
-
#update_zonal_shift(params = {}) ⇒ Types::ZonalShift
Update an active zonal shift in Amazon Application Recovery Controller in your Amazon Web Services account.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-arczonalshift/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1595 1596 1597 |
# File 'lib/aws-sdk-arczonalshift/client.rb', line 1595 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1598 1599 1600 |
# File 'lib/aws-sdk-arczonalshift/client.rb', line 1598 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1568 1569 1570 1571 1572 1573 1574 1575 1576 1577 1578 1579 1580 1581 1582 1583 1584 |
# File 'lib/aws-sdk-arczonalshift/client.rb', line 1568 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::ARCZonalShift') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-arczonalshift' context[:gem_version] = '1.51.0' Seahorse::Client::Request.new(handlers, context) end |
#cancel_practice_run(params = {}) ⇒ Types::CancelPracticeRunResponse
Cancel an in-progress practice run zonal shift in Amazon Application Recovery Controller.
92 |
# File 'sig/client.rbs', line 92
def cancel_practice_run: (
|
#cancel_zonal_shift(params = {}) ⇒ Types::ZonalShift
Cancel a zonal shift in Amazon Application Recovery Controller. To cancel the zonal shift, specify the zonal shift ID.
A zonal shift can be one that you've started for a resource in your Amazon Web Services account in an Amazon Web Services Region, or it can be a zonal shift started by a practice run with zonal autoshift.
108 |
# File 'sig/client.rbs', line 108
def cancel_zonal_shift: (
|
#create_practice_run_configuration(params = {}) ⇒ Types::CreatePracticeRunConfigurationResponse
A practice run configuration for zonal autoshift is required when you enable zonal autoshift. A practice run configuration includes specifications for blocked dates and blocked time windows, and for Amazon CloudWatch alarms that you create to use with practice runs. The alarms that you specify are an outcome alarm, to monitor application health during practice runs and, optionally, a blocking alarm, to block practice runs from starting.
When a resource has a practice run configuration, ARC starts zonal shifts for the resource weekly, to shift traffic for practice runs. Practice runs help you to ensure that shifting away traffic from an Availability Zone during an autoshift is safe for your application.
For more information, see Considerations when you configure zonal autoshift in the Amazon Application Recovery Controller Developer Guide.
121 |
# File 'sig/client.rbs', line 121
def create_practice_run_configuration: (
|
#delete_practice_run_configuration(params = {}) ⇒ Types::DeletePracticeRunConfigurationResponse
Deletes the practice run configuration for a resource. Before you can delete a practice run configuration for a resource., you must disable zonal autoshift for the resource. Practice runs must be configured for zonal autoshift to be enabled.
148 |
# File 'sig/client.rbs', line 148
def delete_practice_run_configuration: (
|
#get_autoshift_observer_notification_status(params = {}) ⇒ Types::GetAutoshiftObserverNotificationStatusResponse
Returns the status of the autoshift observer notification. Autoshift
observer notifications notify you through Amazon EventBridge when
there is an autoshift event for zonal autoshift. The status can be
ENABLED or DISABLED. When ENABLED, a notification is sent when
an autoshift is triggered. When DISABLED, notifications are not
sent.
158 |
# File 'sig/client.rbs', line 158
def get_autoshift_observer_notification_status: (
|
#get_managed_resource(params = {}) ⇒ Types::GetManagedResourceResponse
Get information about a resource that's been registered for zonal shifts with Amazon Application Recovery Controller in this Amazon Web Services Region. Resources that are registered for zonal shifts are managed resources in ARC. You can start zonal shifts and configure zonal autoshift for managed resources.
173 |
# File 'sig/client.rbs', line 173
def get_managed_resource: (
|
#list_autoshifts(params = {}) ⇒ Types::ListAutoshiftsResponse
Returns the autoshifts for an Amazon Web Services Region. By default,
the call returns only ACTIVE autoshifts. Optionally, you can specify
the status parameter to return COMPLETED autoshifts.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
184 |
# File 'sig/client.rbs', line 184
def list_autoshifts: (
|
#list_managed_resources(params = {}) ⇒ Types::ListManagedResourcesResponse
Lists all the resources in your Amazon Web Services account in this Amazon Web Services Region that are managed for zonal shifts in Amazon Application Recovery Controller, and information about them. The information includes the zonal autoshift status for the resource, as well as the Amazon Resource Name (ARN), the Availability Zones that each resource is deployed in, and the resource name.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
197 |
# File 'sig/client.rbs', line 197
def list_managed_resources: (
|
#list_zonal_shifts(params = {}) ⇒ Types::ListZonalShiftsResponse
Lists all active and completed zonal shifts in Amazon Application
Recovery Controller in your Amazon Web Services account in this Amazon
Web Services Region. ListZonalShifts returns customer-initiated
zonal shifts, as well as practice run zonal shifts that ARC started on
your behalf for zonal autoshift.
For more information about listing autoshifts, see ">ListAutoshifts.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
209 |
# File 'sig/client.rbs', line 209
def list_zonal_shifts: (
|
#start_practice_run(params = {}) ⇒ Types::StartPracticeRunResponse
Start an on-demand practice run zonal shift in Amazon Application Recovery Controller. With zonal autoshift enabled, you can start an on-demand practice run to verify preparedness at any time. Amazon Web Services also runs automated practice runs about weekly when you have enabled zonal autoshift.
For more information, see Considerations when you configure zonal autoshift in the Amazon Application Recovery Controller Developer Guide.
228 |
# File 'sig/client.rbs', line 228
def start_practice_run: (
|
#start_zonal_shift(params = {}) ⇒ Types::ZonalShift
You start a zonal shift to temporarily move load balancer traffic away from an Availability Zone in an Amazon Web Services Region, to help your application recover immediately, for example, from a developer's bad code deployment or from an Amazon Web Services infrastructure failure in a single Availability Zone. You can start a zonal shift in ARC only for managed resources in your Amazon Web Services account in an Amazon Web Services Region. Resources are automatically registered with ARC by Amazon Web Services services.
Amazon Application Recovery Controller currently supports enabling the following resources for zonal shift and zonal autoshift:
When you start a zonal shift, traffic for the resource is no longer routed to the Availability Zone. The zonal shift is created immediately in ARC. However, it can take a short time, typically up to a few minutes, for existing, in-progress connections in the Availability Zone to complete.
For more information, see Zonal shift in the Amazon Application Recovery Controller Developer Guide.
246 |
# File 'sig/client.rbs', line 246
def start_zonal_shift: (
|
#update_autoshift_observer_notification_status(params = {}) ⇒ Types::UpdateAutoshiftObserverNotificationStatusResponse
Update the status of autoshift observer notification. Autoshift observer notification enables you to be notified, through Amazon EventBridge, when there is an autoshift event for zonal autoshift.
If the status is ENABLED, ARC includes all autoshift events when you
use the EventBridge pattern Autoshift In Progress. When the status
is DISABLED, ARC includes only autoshift events for autoshifts when
one or more of your resources is included in the autoshift.
For more information, see Notifications for practice runs and autoshifts in the Amazon Application Recovery Controller Developer Guide.
259 |
# File 'sig/client.rbs', line 259
def update_autoshift_observer_notification_status: (
|
#update_practice_run_configuration(params = {}) ⇒ Types::UpdatePracticeRunConfigurationResponse
Update a practice run configuration to change one or more of the following: add, change, or remove the blocking alarm; change the outcome alarm; or add, change, or remove blocking dates or time windows.
272 |
# File 'sig/client.rbs', line 272
def update_practice_run_configuration: (
|
#update_zonal_autoshift_configuration(params = {}) ⇒ Types::UpdateZonalAutoshiftConfigurationResponse
The zonal autoshift configuration for a resource includes the practice run configuration and the status for running autoshifts, zonal autoshift status. When a resource has a practice run configuration, ARC starts weekly zonal shifts for the resource, to shift traffic away from an Availability Zone. Weekly practice runs help you to make sure that your application can continue to operate normally with the loss of one Availability Zone.
You can update the zonal autoshift status to enable or disable zonal
autoshift. When zonal autoshift is ENABLED, you authorize Amazon Web
Services to shift away resource traffic for an application from an
Availability Zone during events, on your behalf, to help reduce time
to recovery. Traffic is also shifted away for the required weekly
practice runs.
298 |
# File 'sig/client.rbs', line 298
def update_zonal_autoshift_configuration: (
|
#update_zonal_shift(params = {}) ⇒ Types::ZonalShift
Update an active zonal shift in Amazon Application Recovery Controller in your Amazon Web Services account. You can update a zonal shift to set a new expiration, or edit or replace the comment for the zonal shift.
315 |
# File 'sig/client.rbs', line 315
def update_zonal_shift: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1588 1589 1590 |
# File 'lib/aws-sdk-arczonalshift/client.rb', line 1588 def waiter_names [] end |