Class: Aws::ARCZonalShift::Types::CancelPracticeRunResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-arczonalshift/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#away_from ⇒ String

The Availability Zone (for example, use1-az1) that traffic was moved away from for a resource that you specified for the practice run.

Returns:

  • (String)


198
199
200
201
202
203
204
205
206
207
208
# File 'lib/aws-sdk-arczonalshift/types.rb', line 198

class CancelPracticeRunResponse < Struct.new(
  :zonal_shift_id,
  :resource_identifier,
  :away_from,
  :expiry_time,
  :start_time,
  :status,
  :comment)
  SENSITIVE = []
  include Aws::Structure
end

#comment ⇒ String

The initial comment that you entered about the practice run. Be aware that this comment can be overwritten by Amazon Web Services if the automatic check for balanced capacity fails. For more information, see Capacity checks for practice runs in the Amazon Application Recovery Controller Developer Guide.

Returns:

  • (String)


198
199
200
201
202
203
204
205
206
207
208
# File 'lib/aws-sdk-arczonalshift/types.rb', line 198

class CancelPracticeRunResponse < Struct.new(
  :zonal_shift_id,
  :resource_identifier,
  :away_from,
  :expiry_time,
  :start_time,
  :status,
  :comment)
  SENSITIVE = []
  include Aws::Structure
end

#expiry_time ⇒ Time

The expiry time (expiration time) for an on-demand practice run zonal shift is 30 minutes from the time when you start the practice run, unless you cancel it before that time. However, be aware that the expiryTime field for practice run zonal shifts always has a value of 1 minute.

Returns:

  • (Time)


198
199
200
201
202
203
204
205
206
207
208
# File 'lib/aws-sdk-arczonalshift/types.rb', line 198

class CancelPracticeRunResponse < Struct.new(
  :zonal_shift_id,
  :resource_identifier,
  :away_from,
  :expiry_time,
  :start_time,
  :status,
  :comment)
  SENSITIVE = []
  include Aws::Structure
end

#resource_identifier ⇒ String

The identifier for the resource that you canceled a practice run zonal shift for. The identifier is the Amazon Resource Name (ARN) for the resource.

Returns:

  • (String)


198
199
200
201
202
203
204
205
206
207
208
# File 'lib/aws-sdk-arczonalshift/types.rb', line 198

class CancelPracticeRunResponse < Struct.new(
  :zonal_shift_id,
  :resource_identifier,
  :away_from,
  :expiry_time,
  :start_time,
  :status,
  :comment)
  SENSITIVE = []
  include Aws::Structure
end

#start_time ⇒ Time

The time (UTC) when the zonal shift starts.

Returns:

  • (Time)


198
199
200
201
202
203
204
205
206
207
208
# File 'lib/aws-sdk-arczonalshift/types.rb', line 198

class CancelPracticeRunResponse < Struct.new(
  :zonal_shift_id,
  :resource_identifier,
  :away_from,
  :expiry_time,
  :start_time,
  :status,
  :comment)
  SENSITIVE = []
  include Aws::Structure
end

#status ⇒ String

A status for the practice run that you canceled (expected status is CANCELED).

The Status for a practice run zonal shift can have one of the following values:

Returns:

  • (String)


198
199
200
201
202
203
204
205
206
207
208
# File 'lib/aws-sdk-arczonalshift/types.rb', line 198

class CancelPracticeRunResponse < Struct.new(
  :zonal_shift_id,
  :resource_identifier,
  :away_from,
  :expiry_time,
  :start_time,
  :status,
  :comment)
  SENSITIVE = []
  include Aws::Structure
end

#zonal_shift_id ⇒ String

The identifier of the practice run zonal shift in Amazon Application Recovery Controller that was canceled.

Returns:

  • (String)


198
199
200
201
202
203
204
205
206
207
208
# File 'lib/aws-sdk-arczonalshift/types.rb', line 198

class CancelPracticeRunResponse < Struct.new(
  :zonal_shift_id,
  :resource_identifier,
  :away_from,
  :expiry_time,
  :start_time,
  :status,
  :comment)
  SENSITIVE = []
  include Aws::Structure
end